@@ -1,5 +1,5 @@
-#!/bin/bash
-#  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+#!/bin/sh
+#  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #
 # Sets up resolver (/etc/resolv.conf) in a container.
 
-function set_dns()
+set_dns()
 {
 	local cfgfile="$1"
 	local server="$2"
@@ -30,7 +30,7 @@ function set_dns()
 	fi
 	if [ -n "${server}" ]; then
 		[ -f ${cfgfile} ] || touch ${cfgfile}
-		sed "/nameserver.*/d" < ${cfgfile} > ${cfgfile}.$$ &&
+		sed '/^\s*nameserver\s/d' ${cfgfile} > ${cfgfile}.$$ &&
 			mv -f ${cfgfile}.$$ ${cfgfile} ||
 			error "Can't change file ${cfgfile}" ${VZ_FS_NO_DISK_SPACE}
 		for srv in ${server}; do
@@ -40,7 +40,18 @@ function set_dns()
 	chmod 644 ${cfgfile}
 }
 
+gen_resolvconf() {
+	local ns
+	[ -n "${SEARCHDOMAIN}" ] && echo "search ${SEARCHDOMAIN}"
+	for ns in ${NAMESERVER}; do
+		echo "nameserver $ns"
+	done
+}
 
-set_dns /etc/resolv.conf "${NAMESERVER}" "${SEARCHDOMAIN}"
+if which resolvconf >/dev/null 2>&1; then
+	gen_resolvconf | resolvconf -a venet0
+else
+	set_dns /etc/resolv.conf "${NAMESERVER}" "${SEARCHDOMAIN}"
+fi
 
 exit 0
