@@ -144,10 +144,14 @@
 #define PARAM_SNAPSHOT_DESC	372
 #define PARAM_SNAPSHOT_SKIP_SUSPEND	373
 #define PARAM_SNAPSHOT_SKIP_CONFIG	375
+#define PARAM_SNAPSHOT_MOUNT_TARGET	376
 
 #define PARAM_SKIP_UMOUNT	374
 #define PARAM_MOUNT_OPTS	396
 
 
+#define PARAM_LOCAL_UID		397
+#define PARAM_LOCAL_GID		398
+
 #define PARAM_LINE		"e:p:f:t:i:l:k:a:b:n:x:h"
 #endif
