@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2013, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,9 +15,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -2363,7 +2360,7 @@ vps_param *reread_vps_config(envid_t veid)
 	char fname[PATH_MAX];
 
 	get_vps_conf_path(veid, fname, sizeof(fname));
-	if (stat_file(fname))
+	if (stat_file(fname) != 1)
 		goto err;
 
 	gparam = init_vps_param();
@@ -2394,7 +2391,7 @@ static int read_conf(char *fname, list_head_t *conf_h)
 	FILE *fp;
 	char str[16384];
 
-	if (!stat_file(fname))
+	if (stat_file(fname) != 1)
 		return 0;
 	if (!(fp = fopen(fname, "r")))
 		return -1;
@@ -2502,7 +2499,7 @@ int vps_save_config(envid_t veid, char *path, vps_param *new_p,
 	list_head_init(&new_conf);
 	if (old_p == NULL) {
 		tmp_old_p = init_vps_param();
-		if (stat_file(path))
+		if (stat_file(path) == 1)
 			vps_parse_config(veid, path, tmp_old_p, action);
 		old_p = tmp_old_p;
 	}
