@@ -175,7 +175,7 @@ static int destroydir(char *dir)
 	}
 	snprintf(tmp, sizeof(tmp), "%s/vztmp", root);
 	free(root);
-	if (!stat_file(tmp)) {
+	if (stat_file(tmp) != 1) {
 		if (mkdir(tmp, 0755)) {
 			logger(-1, errno, "Can't create tmp dir %s", tmp);
 			return VZ_FS_DEL_PRVT;
@@ -233,15 +233,19 @@ static int destroydir(char *dir)
 	return ret;
 }
 
-static int destroy_dumpfile(envid_t veid, const char *dumpdir)
+int destroy_dump(envid_t veid, const char *dumpdir)
 {
 	char buf[128];
 
 	get_dump_file(veid, dumpdir, buf, sizeof(buf));
+
+	logger(1, 0, "Removing CT dump %s", buf);
 	if (unlink(buf) == 0)
 		return 0;
 	else if (errno == ENOENT)
 		return 0;
+	else if (errno == EISDIR)
+		return del_dir(buf);
 	else return -1;
 }
 
@@ -265,7 +269,7 @@ int vps_destroy(vps_handler *h, envid_t veid, fs_param *fs, cpt_param *cpt)
 	if ((ret = vps_destroy_dir(veid, fs->private)))
 		return ret;
 	move_config(veid, BACKUP);
-	if (destroy_dumpfile(veid, cpt != NULL ? cpt->dumpdir : NULL) < 0)
+	if (destroy_dump(veid, cpt != NULL ? cpt->dumpdir : NULL) < 0)
 		logger(-1, errno, "Warning: failed to remove dump file");
 	if (rmdir(fs->root) < 0)
 		logger(-1, errno, "Warning: failed to remove %s", fs->root);
