@@ -45,6 +45,7 @@
 #include "cpt.h"
 #include "image.h"
 #include "readelf.h"
+#include "destroy.h"
 
 static int env_stop(vps_handler *h, envid_t veid, const char *root,
 		int stop_mode);
@@ -89,7 +90,7 @@ vps_handler *vz_open(envid_t veid, vps_param *param)
 
 #ifdef VZ_KERNEL_SUPPORTED
 	/* Find out if we are under OpenVZ or upstream kernel */
-	if (stat_file("/proc/vz"))
+	if (stat_file("/proc/vz") == 1)
 		ret = vz_do_open(h, param);
 	else
 #endif
@@ -262,7 +263,7 @@ int exec_container_init(struct arg_start *arg,
 	}
 
 	mount("proc", "/proc", "proc", 0, 0);
-	if (stat_file("/sys"))
+	if (stat_file("/sys") == 1)
 		mount("sysfs", "/sys", "sysfs", 0, 0);
 
 	if (create_param->feature_mask & VE_FEATURE_NFSD) {
@@ -634,10 +635,14 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	 * sending data.
 	 */
 	if (pipe(old_wait_p) < 0) {
+		close(wait_p[0]);
+		close(wait_p[1]);
 		logger(-1, errno, "Can not create pipe");
 		return VZ_RESOURCE_ERROR;
 	}
 	if (pipe(err_p) < 0) {
+		close(old_wait_p[0]);
+		close(old_wait_p[1]);
 		close(wait_p[0]);
 		close(wait_p[1]);
 		logger(-1, errno, "Can not create pipe");
@@ -660,7 +665,7 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	{
 		goto err;
 	}
-	if (!(skip & SKIP_ACTION_SCRIPT)) {
+	if (!(skip & SKIP_ACTION_SCRIPT) && !fn) {
 
 		/* Run dist actions PRE_START script */
 		if (actions.pre_start) {
@@ -685,7 +690,7 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 		/* Run per-CT $VEID.start script */
 		snprintf(buf, sizeof(buf), VPS_CONF_DIR "%d.%s", veid,
 			START_PREFIX);
-		if (stat_file(buf)) {
+		if (stat_file(buf) == 1) {
 			if (vps_exec_script(h, veid, res->fs.root, NULL, NULL,
 				buf, NULL, 0))
 			{
@@ -750,6 +755,8 @@ err:
 				!(skip & SKIP_UMOUNT))
 			vps_umount(h, veid, &res->fs, skip);
 	}
+	close(old_wait_p[0]);
+	close(old_wait_p[1]);
 	close(wait_p[0]);
 	close(wait_p[1]);
 	close(err_p[0]);
@@ -779,15 +786,7 @@ int vps_start(vps_handler *h, envid_t veid, vps_param *param,
 		/* Start was successful, remove the default dump file:
 		 * it is now useless and inconsistent with the fs state
 		 */
-		char buf[STR_SIZE];
-
-		get_dump_file(veid, param->res.cpt.dumpdir, buf, sizeof(buf));
-		if (stat_file(buf) == 1) {
-			logger(0, 0, "Stale CT dump file %s found, removing",
-					buf);
-			if (unlink(buf) < 0)
-				logger(-1, 0, "Can't unlink %s", buf);
-		}
+		destroy_dump(veid, param->res.cpt.dumpdir);
 	}
 
 	return ret;
@@ -890,7 +889,10 @@ static int env_stop(vps_handler *h, envid_t veid, const char *root,
 		ret = real_env_stop(h, veid, root, stop_mode);
 		exit(ret);
 	}
-	if (wait_child(pid, 0)) /* reboot/halt failed, retry with kill */
+
+	ret = wait_child(pid, 0);
+	/* Sometimes reboot/halt returns 1 but still stops the CT */
+	if (ret != 0 && ret != 1) /* failed, retry with kill */
 		goto kill_vps;
 
 	for (i = 0; i < MAX_SHTD_TM; i++) {
@@ -966,7 +968,7 @@ int vps_stop(vps_handler *h, envid_t veid, vps_param *param, int stop_mode,
 	if (!(skip & SKIP_ACTION_SCRIPT)) {
 		snprintf(buf, sizeof(buf), VPS_CONF_DIR "%d.%s", veid,
 			STOP_PREFIX);
-		if (stat_file(buf)) {
+		if (stat_file(buf) == 1) {
 			if (vps_exec_script(h, veid, res->fs.root, NULL, NULL,
 				buf, NULL, 0))
 			{
