@@ -171,12 +171,12 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
 				veid, PRE_MOUNT_PREFIX);
 		}
 	}
-	if (!stat_file(fs->private)) {
+	if (stat_file(fs->private) != 1) {
 		logger(-1, 0, "Container private area %s does not exist",
 				fs->private);
 		return VZ_FS_NOPRVT;
 	}
-	if (!stat_file(fs->private)) {
+	if (stat_file(fs->private) != 1) {
 		logger(-1, 0, "Container private area %s does not exist",
 				fs->private);
 		return VZ_FS_NOPRVT;
