@@ -391,15 +391,16 @@ static int ct_env_create_real(struct arg_start *arg)
 	int userns_p[2];
 	int ret, fd;
 	char pidpath[STR_SIZE];
+	char ctpath[STR_SIZE];
 
 	stack_size = get_pagesize();
 	if (stack_size < 0)
-		return -VZ_RESOURCE_ERROR;
+		return VZ_RESOURCE_ERROR;
 
 	child_stack = alloca(stack_size);
 	if (child_stack == NULL) {
 		logger(-1, 0, "Unable to alloc");
-		return -VZ_RESOURCE_ERROR;
+		return VZ_RESOURCE_ERROR;
 	}
 	child_stack += stack_size;
 
@@ -418,7 +419,7 @@ static int ct_env_create_real(struct arg_start *arg)
 		clone_flags |= CLONE_NEWUSER;
 		if (pipe(userns_p) < 0) {
 			logger(-1, errno, "Can not create userns pipe");
-			return -VZ_RESOURCE_ERROR;
+			return VZ_RESOURCE_ERROR;
 		}
 	}
 	arg->userns_p = userns_p[0];
@@ -439,7 +440,7 @@ static int ct_env_create_real(struct arg_start *arg)
 		/* FIXME: remove ourselves from container first */
 		close(userns_p[1]);
 		destroy_container(arg->veid);
-		return -VZ_RESOURCE_ERROR;
+		return VZ_RESOURCE_ERROR;
 	}
 
 	dprintf(fd, "%d", ret);
@@ -459,7 +460,7 @@ static int ct_env_create_real(struct arg_start *arg)
 			logger(-1, 0, "Can't write to userns mapping file");
 			close(userns_p[1]);
 			destroy_container(arg->veid);
-			return -VZ_RESOURCE_ERROR;
+			return VZ_RESOURCE_ERROR;
 		}
 		/*
 		 * Nothing should proceed userns wide until we have the
@@ -474,18 +475,25 @@ static int ct_env_create_real(struct arg_start *arg)
 			logger(-1, errno, "Unable to write to userns pipe");
 			close(userns_p[1]);
 			destroy_container(arg->veid);
-			return -VZ_RESOURCE_ERROR;
+			return VZ_RESOURCE_ERROR;
 		}
 		close(userns_p[1]);
 	}
 
-	return ret;
+	snprintf(ctpath, STR_SIZE, "%s/%d", NETNS_RUN_DIR, arg->veid);
+	snprintf(pidpath, STR_SIZE, "/proc/%d/ns/net", ret);
+	if (symlink(pidpath, ctpath)) {
+		logger(-1, errno, "Can't symlink into netns file %s", ctpath);
+		destroy_container(arg->veid);
+		return VZ_RESOURCE_ERROR;
+	}
+
+	return 0;
 }
 
 int ct_env_create(struct arg_start *arg)
 {
 	int ret;
-	char procpath[STR_SIZE];
 	char ctpath[STR_SIZE];
 
 	/* non-fatal */
@@ -513,22 +521,12 @@ int ct_env_create(struct arg_start *arg)
 
 	/* Return PID on success or -VZ_*_ERROR */
 	if (arg->fn)
-		ret = arg->fn(arg->h, arg->veid, &arg->res->fs,
+		ret = arg->fn(arg->h, arg->veid, arg->res,
 				arg->wait_p, arg->old_wait_p, arg->err_p, arg->data);
 	else
 		ret = ct_env_create_real(arg);
-	if (ret < 0)
-		return -ret;
 
-	snprintf(procpath, STR_SIZE, "/proc/%d/ns/net", ret);
-	ret = symlink(procpath, ctpath);
-	if (ret) {
-		logger(-1, errno, "Can't symlink into netns file %s", ctpath);
-		destroy_container(arg->veid);
-		return VZ_RESOURCE_ERROR;
-	}
-
-	return 0;
+	return ret;
 }
 
 static int ct_enter(vps_handler *h, envid_t veid, const char *root, int flags)
@@ -816,7 +814,7 @@ static int ct_ip_ctl(vps_handler *h, envid_t veid, int op, const char *ipstr)
 static int ct_veth_ctl(vps_handler *h, envid_t veid, int op, veth_dev *dev)
 {
 	int ret = -1;
-	char *envp[10];
+	char *envp[11];
 	char buf[STR_SIZE];
 	int i = 0;
 
@@ -848,6 +846,12 @@ static int ct_veth_ctl(vps_handler *h, envid_t veid, int op, veth_dev *dev)
 		envp[i++] = strdup(buf);
 	}
 
+	if (op == ADD)
+		snprintf(buf, sizeof(buf), "ACTION=add");
+	else
+		snprintf(buf, sizeof(buf), "ACTION=cfg");
+	envp[i++] = strdup(buf);
+
 	envp[i] = NULL;
 
 	if (op == ADD) {
@@ -916,17 +920,16 @@ static int ct_chkpnt(vps_handler *h, envid_t veid,
 	return ret;
 }
 
-static int ct_restore_fn(vps_handler *h, envid_t veid, const fs_param *fs,
+static int ct_restore_fn(vps_handler *h, envid_t veid, const vps_res *res,
 			  int wait_p, int old_wait_p, int err_p, void *data)
 {
-	char *argv[2], *env[4];
+	char *argv[2], *env[9];
 	const char *dumpfile = NULL;
 	const char *statefile = NULL;
 	cpt_param *param = data;
-	char buf[STR_SIZE];
-	pid_t pid = -1;
+	veth_dev *veth;
+	char buf[STR_SIZE], *pbuf;
 	int ret;
-	FILE *sfile;
 
 	get_dump_file(veid, param->dumpdir, buf, sizeof(buf));
 	dumpfile = strdup(buf);
@@ -937,41 +940,45 @@ static int ct_restore_fn(vps_handler *h, envid_t veid, const fs_param *fs,
 	argv[0] = SCRIPTDIR "/vps-rst";
 	argv[1] = NULL;
 
-	snprintf(buf, sizeof(buf), "VE_ROOT=%s", fs->root);
+	snprintf(buf, sizeof(buf), "VE_ROOT=%s", res->fs.root);
 	env[0] = strdup(buf);
 	snprintf(buf, sizeof(buf), "VE_DUMP_DIR=%s", dumpfile);
 	env[1] = strdup(buf);
 	snprintf(buf, sizeof(buf), "VE_STATE_FILE=%s", statefile);
 	env[2] = strdup(buf);
-	env[3] = NULL;
+
+	pbuf = buf;
+	pbuf += snprintf(buf, sizeof(buf), "VE_VETH_DEVS=");
+	list_for_each(veth, &res->veth.dev, list) {
+		pbuf += snprintf(pbuf, sizeof(buf) - (pbuf - buf),
+				"%s=%s\n", veth->dev_name_ve, veth->dev_name);
+	}
+	env[3] = strdup(buf);
+	snprintf(buf, sizeof(buf), "VZCTL_PID=%d", getpid());
+	env[4] = strdup(buf);
+	snprintf(buf, sizeof(buf), "STATUSFD=%d", STDIN_FILENO);
+	env[5] = strdup(buf);
+	snprintf(buf, sizeof(buf), "WAITFD=%d", wait_p);
+	env[6] = strdup(buf);
+	snprintf(buf, sizeof(buf), "VE_NETNS_FILE=%s/%d", NETNS_RUN_DIR, veid);
+	env[7] = strdup(buf);
+	env[8] = NULL;
 
 	ret = run_script(argv[0], argv, env, 0);
 	free_arg(env);
-	if (ret)
-		return -VZ_RESTORE_ERROR;
-
-	sfile = fopen(statefile, "r");
-	if (sfile == NULL) {
-		logger(-1, errno, "Unable to open %s", statefile);
-		goto err_destroy;
+	if (ret) {
+		destroy_container(veid);
+		return VZ_RESTORE_ERROR;
 	}
 
-	if (fscanf(sfile, "%d", &pid) != 1)
-		logger(-1, errno, "Unable to read PID from %s", statefile);
-
-	fclose(sfile);
-err_destroy:
-	if (pid < 0)
-		destroy_container(veid);
-
-	return pid > 0 ? pid : -VZ_RESTORE_ERROR;
+	return 0;
 }
 
 static int ct_restore(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 	cpt_param *param, skipFlags skip)
 {
 	return vps_start_custom(h, veid, vps_p,
-			SKIP_CONFIGURE | SKIP_ACTION_SCRIPT | skip,
+			SKIP_CONFIGURE | SKIP_VETH_CREATE | skip,
 			NULL, ct_restore_fn, param);
 }
 
