@@ -486,7 +486,7 @@ static int compact(vps_handler *h, envid_t veid, vps_param *g_p,
 	if (check_var(private, "VE_PRIVATE is not set"))
 		return VZ_VE_PRIVATE_NOTSET;
 
-	if (!stat_file(private)) {
+	if (stat_file(private) != 1) {
 		logger(-1, 0, "Container private area %s does not exist",
 				private);
 		return VZ_FS_NOPRVT;
@@ -879,7 +879,7 @@ static int apply_param_from_cfg(int veid, vps_param *param, char *cfg)
 	if (cfg == NULL)
 		return 0;
 	snprintf(conf, sizeof(conf), VPS_CONF_DIR "ve-%s.conf-sample", cfg);
-	if (!stat_file(conf)) {
+	if (stat_file(conf) != 1) {
 		logger(-1, 0, "Sample config file not found: %s", conf);
 		return VZ_APPLY_CONFIG_ERROR;
 	}
@@ -1181,7 +1181,7 @@ static int vps_set(vps_handler *h, envid_t veid,
 
 		get_vps_conf_path(veid, fname, sizeof(fname));
 		/* Warn if config does not exist */
-		if (!stat_file(fname))
+		if (stat_file(fname) != 1)
 			logger(-1, errno, "WARNING: %s not found", fname);
 
 		ret = vps_save_config(veid, fname, cmd_p, vps_p, &g_action);
@@ -1327,19 +1327,18 @@ static int restore(vps_handler *h, envid_t veid, vps_param *g_p,
 
 static int show_status(vps_handler *h, envid_t veid, vps_param *param)
 {
-	int exist = 0, mounted = 0, run = 0, suspended = 0;
+	int exist, mounted, run, suspended = 0;
 	char buf[STR_SIZE];
 	fs_param *fs = &param->res.fs;
 
 	get_vps_conf_path(veid, buf, sizeof(buf));
-	if (fs->private != NULL && stat_file(fs->private) && stat_file(buf))
-		exist = 1;
+	exist = (fs->private != NULL && stat_file(fs->private) == 1
+			&& stat_file(buf) == 1);
 	mounted = (vps_is_mounted(fs->root, fs->private) == 1);
 	run = vps_is_run(h, veid);
 	if (exist && !run) {
 		get_dump_file(veid, param->res.cpt.dumpdir, buf, sizeof(buf));
-		if (stat_file(buf))
-			suspended = 1;
+		suspended = (stat_file(buf) == 1);
 	}
 	printf("CTID %d %s %s %s%s\n", veid,
 		exist ? "exist" : "deleted",
